API
==============================

Reading data in FASTGenomics
-----------------------------
.. autofunction:: fgread.ds_info
.. autofunction:: fgread.load_data


Readers for supported formats
-----------------------------

.. automodule:: fgread.readers
   :members:
